==> tencentcloud-sdk-python-intl-en-3.0.1069.tar.gz: tencentcloud-sdk-python-intl-en-3.0.1069/tencentcloud/billing/v20180709/errorcodes.py <==
# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# No permission.
AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'

# Operation failed.
FAILEDOPERATION = 'FailedOperation'

# Invalid App ID.
FAILEDOPERATION_INVALIDAPPID = 'FailedOperation.InvalidAppId'

# Payment failed. Please contact Tencent Cloud to resolve this issue.
FAILEDOPERATION_PAYPRICEERROR = 'FailedOperation.PayPriceError'

# Failed to get the number of data entries.
FAILEDOPERATION_QUERYCOUNTFAILED = 'FailedOperation.QueryCountFailed'

# Summary is being built. Please try again later.
FAILEDOPERATION_SUMMARYDATANOTREADY = 'FailedOperation.SummaryDataNotReady'

# This cost allocation tag key does not exist.
FAILEDOPERATION_TAGKEYNOTEXIST = 'FailedOperation.TagKeyNotExist'

# Internal error.
INTERNALERROR = 'InternalError'

# Gateway error.
INTERNALERROR_GATEWAYERROR = 'InternalError.GatewayError'

# Undefined exception.
INTERNALERROR_UNKNOWNERROR = 'InternalError.UnknownError'

# Invalid parameter.
INVALIDPARAMETER = 'InvalidParameter'

# Invalid parameter value.
INVALIDPARAMETERVALUE = 'InvalidParameterValue'

# The account does not have CAM permission.
UNAUTHORIZEDOPERATION_CAMNOAUTH = 'UnauthorizedOperation.CamNoAuth'

# Operation unsupported.
UNSUPPORTEDOPERATION = 'UnsupportedOperation'

==> tencentcloud-sdk-python-intl-en-3.0.1240.tar.gz: tencentcloud-sdk-python-intl-en-3.0.1240/tencentcloud/billing/v20180709/errorcodes.py <==
# -*- coding: utf8 -*-
# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# No permission.
AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'

# Operation failed.
FAILEDOPERATION = 'FailedOperation'

# Invalid App ID.
FAILEDOPERATION_INVALIDAPPID = 'FailedOperation.InvalidAppId'

# The quantity exceeds the maximum limit.
FAILEDOPERATION_NUMLIMITERROR = 'FailedOperation.NumLimitError'

# Payment failed. Please contact Tencent Cloud to resolve this issue.
FAILEDOPERATION_PAYPRICEERROR = 'FailedOperation.PayPriceError'

# Failed to get the number of data entries.
FAILEDOPERATION_QUERYCOUNTFAILED = 'FailedOperation.QueryCountFailed'

# Summary is being built. Please try again later.
FAILEDOPERATION_SUMMARYDATANOTREADY = 'FailedOperation.SummaryDataNotReady'

# This cost allocation tag key does not exist.
FAILEDOPERATION_TAGKEYNOTEXIST = 'FailedOperation.TagKeyNotExist'

# Internal error.
INTERNALERROR = 'InternalError'

# Database operation failed.
INTERNALERROR_DBOPERATERROR = 'InternalError.DbOperatError'

# Gateway error.
INTERNALERROR_GATEWAYERROR = 'InternalError.GatewayError'

# An internal system error occurred.
INTERNALERROR_INTERNALERROR = 'InternalError.InternalError'

# Undefined exception.
INTERNALERROR_UNKNOWNERROR = 'InternalError.UnknownError'

# Invalid parameter.
INVALIDPARAMETER = 'InvalidParameter'

# A parameter error occurred.
INVALIDPARAMETER_INVALIDPARAMETER = 'InvalidParameter.InvalidParameter'

# Invalid parameter value.
INVALIDPARAMETERVALUE = 'InvalidParameterValue'

# Operation denied.
OPERATIONDENIED = 'OperationDenied'

# The account does not have CAM permission.
UNAUTHORIZEDOPERATION_CAMNOAUTH = 'UnauthorizedOperation.CamNoAuth'

# Operation unsupported.
UNSUPPORTEDOPERATION = 'UnsupportedOperation'
